const std = @import("std");

pub fn build(b: *std.Build) void {
    const target = b.standardTargetOptions(.{});

    const optimize = b.standardOptimizeOption(.{});

    const geojson_lib = b.addStaticLibrary(.{
        .name = "geojson.zig",
        .root_source_file = b.path("src/geojson.zig"),
        .target = target,
        .optimize = optimize,
    });

    b.installArtifact(geojson_lib);

    const exe = b.addExecutable(.{
        .name = "geojson.zig",
        .root_source_file = b.path("src/main.zig"),
        .target = target,
        .optimize = optimize,
    });

    b.installArtifact(exe);

    const run_cmd = b.addRunArtifact(exe);

    run_cmd.step.dependOn(b.getInstallStep());

    if (b.args) |args| {
        run_cmd.addArgs(args);
    }

    const run_step = b.step("run", "Run the app");
    run_step.dependOn(&run_cmd.step);

    const geojson_lib_unit_tests = b.addTest(.{
        .root_source_file = b.path("src/geojson.zig"),
        .target = target,
        .optimize = optimize,
    });
    const run_geojson_lib_unit_tests = b.addRunArtifact(geojson_lib_unit_tests);

    const exe_unit_tests = b.addTest(.{
        .root_source_file = b.path("src/main.zig"),
        .target = target,
        .optimize = optimize,
    });
    const run_exe_unit_tests = b.addRunArtifact(exe_unit_tests);

    const test_step = b.step("test", "Run unit tests");
    test_step.dependOn(&run_geojson_lib_unit_tests.step);
    test_step.dependOn(&run_exe_unit_tests.step);
}
