{
  description = "geojson.zig";

  inputs = {
    nixpkgs.url = "github:nixos/nixpkgs/nixpkgs-unstable";
    flake-utils.url = "github:numtide/flake-utils";
    flake-compat = {
      url = "github:edolstra/flake-compat";
      flake = false;
    };
    gitignore = {
      url = "github:hercules-ci/gitignore.nix";
      inputs.nixpkgs.follows = "nixpkgs";
    };
    zig.url = "github:mitchellh/zig-overlay";
  };

  outputs = _:
    let
      zigVersion = "0.13.0";
    in
    let
      overlays = [
        (final: prev: {
          zig = _.zig.packages.${prev.system}.${zigVersion};
        })
      ];
      systems = builtins.attrNames _.zig.packages;
      inherit (_.gitignore.lib) gitignoreSource;
    in
    _.flake-utils.lib.eachSystem systems (
      system:
      let
        pkgs = import _.nixpkgs { inherit overlays system; };
      in
      {
        packages = {
          default = pkgs.stdenvNoCC.mkDerivation {
            name = "geojson.zig";
            src = gitignoreSource ./.;
            dontConfigure = true;
            dontInstall = false;
            doCheck = true;
            nativeBuildInputs = [ pkgs.zig ];
            version = "master";
            buildPhase = ''
              mkdir -p .cache
              zig build \
                --cache-dir $(pwd)/zig-cache \
                --global-cache-dir $(pwd)/.cache \
                --prefix $out
            '';
            checkPhase = ''
              zig build test \
                --cache-dir $(pwd)/zig-cache \
                --global-cache-dir $(pwd)/.cache
            '';
          };
        };
        devShells.default = pkgs.mkShell {
          nativeBuildInputs = with pkgs; [
            zig
            lldb
          ];
          shellHook = ''
            zig version
          '';
        };
        formatter = pkgs.nixpkgs-fmt;
      }
    );
}
