const std = @import("std");

fn tile2lon(x: u32, zoom: u32) f64 {
    const tiles = std.math.pow(f64, 2, @floatFromInt(zoom));
    const normalized_x = @as(f64, @floatFromInt(x)) / tiles;
    return normalized_x * 360.0 - 180.0;
}

pub fn tile2lat(y: u32, zoom: u32) f64 {
    const tiles = std.math.pow(f64, 2, @floatFromInt(zoom));
    const n = std.math.pi * (1 - 2 * @as(f64, @floatFromInt(y)) / tiles);
    const lat_rad = std.math.atan(std.math.sinh(n));
    return std.math.radiansToDegrees(lat_rad);
}

pub fn tileToBbox(x: u32, y: u32, zoom: u32) [4]f64 {
    const east = tile2lon(x + 1, zoom);
    const west = tile2lon(x, zoom);
    const south = tile2lat(y + 1, zoom);
    const north = tile2lat(y, zoom);
    return .{ west, south, east, north };
}

test "tile2lon" {
    _ = tile2lon(0, 0);
    _ = tile2lon(0, 1);
    _ = tile2lon(1, 1);
    _ = tile2lon(0, 2);
    _ = tile2lon(3, 2);
}

test "tile2lat" {
    _ = tile2lat(0, 0);
    _ = tile2lat(0, 1);
    _ = tile2lat(1, 1);
    _ = tile2lat(0, 2);
    _ = tile2lat(3, 2);
}

test "tileToBbox" {
    const inputs = .{
        .{ .tile = .{ 5, 10, 10 }, .bbox = .{ -178.2421875, 84.7060489350415, -177.890625, 84.73838712095339 } },
        .{ .tile = .{ 0, 0, 0 }, .bbox = .{ -180.0, -85.05112878, 180.0, 85.05112878 } },
    };
    inline for (inputs) |input| {
        const bbox = tileToBbox(input.tile[0], input.tile[1], input.tile[2]);
        const tolerance = 1e-9; // centimeter-level precision
        try std.testing.expectApproxEqAbs(bbox[0], input.bbox[0], tolerance);
        try std.testing.expectApproxEqAbs(bbox[1], input.bbox[1], tolerance);
        try std.testing.expectApproxEqAbs(bbox[2], input.bbox[2], tolerance);
        try std.testing.expectApproxEqAbs(bbox[3], input.bbox[3], tolerance);
    }
}
